@@ -1,98 +1,64 @@
 <?php
-/**
- * PHPUnit
+/*
+ * This file is part of PHPUnit.
  *
- * Copyright (c) 2001-2014, Sebastian Bergmann <sebastian@phpunit.de>.
- * All rights reserved.
+ * (c) Sebastian Bergmann <sebastian@phpunit.de>
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *   * Redistributions of source code must retain the above copyright
- *     notice, this list of conditions and the following disclaimer.
- *
- *   * Redistributions in binary form must reproduce the above copyright
- *     notice, this list of conditions and the following disclaimer in
- *     the documentation and/or other materials provided with the
- *     distribution.
- *
- *   * Neither the name of Sebastian Bergmann nor the names of his
- *     contributors may be used to endorse or promote products derived
- *     from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- *
- * @package    PHPUnit
- * @subpackage Framework
- * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2001-2014 Sebastian Bergmann <sebastian@phpunit.de>
- * @license    http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
- * @link       http://www.phpunit.de/
- * @since      File available since Release 2.0.0
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
  */
 
+use SebastianBergmann\ResourceOperations\ResourceOperations;
+
 /**
  * A TestResult collects the results of executing a test case.
  *
- * @package    PHPUnit
- * @subpackage Framework
- * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2001-2014 Sebastian Bergmann <sebastian@phpunit.de>
- * @license    http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
- * @link       http://www.phpunit.de/
- * @since      Class available since Release 2.0.0
+ * @since Class available since Release 2.0.0
  */
 class PHPUnit_Framework_TestResult implements Countable
 {
     /**
      * @var array
      */
-    protected $passed = array();
+    protected $passed = [];
 
     /**
      * @var array
      */
-    protected $errors = array();
+    protected $errors = [];
 
     /**
      * @var array
      */
-    protected $failures = array();
+    protected $failures = [];
 
     /**
      * @var array
      */
-    protected $notImplemented = array();
+    protected $warnings = [];
 
     /**
      * @var array
      */
-    protected $risky = array();
+    protected $notImplemented = [];
 
     /**
      * @var array
      */
-    protected $skipped = array();
+    protected $risky = [];
 
     /**
      * @var array
      */
-    protected $listeners = array();
+    protected $skipped = [];
 
     /**
-     * @var integer
+     * @var array
+     */
+    protected $listeners = [];
+
+    /**
+     * @var int
      */
     protected $runTests = 0;
 
@@ -114,80 +80,90 @@ class PHPUnit_Framework_TestResult implements Countable
     protected $codeCoverage;
 
     /**
-     * @var boolean
+     * @var bool
      */
     protected $convertErrorsToExceptions = true;
 
     /**
-     * @var boolean
+     * @var bool
      */
     protected $stop = false;
 
     /**
-     * @var boolean
+     * @var bool
      */
     protected $stopOnError = false;
 
     /**
-     * @var boolean
+     * @var bool
      */
     protected $stopOnFailure = false;
 
     /**
-     * @var boolean
+     * @var bool
+     */
+    protected $stopOnWarning = false;
+
+    /**
+     * @var bool
      */
     protected $beStrictAboutTestsThatDoNotTestAnything = false;
 
     /**
-     * @var boolean
+     * @var bool
      */
     protected $beStrictAboutOutputDuringTests = false;
 
     /**
-     * @var boolean
-     */
-    protected $beStrictAboutTestSize = false;
-
-    /**
-     * @var boolean
+     * @var bool
      */
     protected $beStrictAboutTodoAnnotatedTests = false;
 
     /**
-     * @var boolean
+     * @var bool
      */
-    protected $stopOnRisky = false;
+    protected $beStrictAboutResourceUsageDuringSmallTests = false;
 
     /**
-     * @var boolean
+     * @var bool
      */
-    protected $stopOnIncomplete = false;
+    protected $enforceTimeLimit = false;
 
     /**
-     * @var boolean
-     */
-    protected $stopOnSkipped = false;
-
-    /**
-     * @var boolean
-     */
-    protected $lastTestFailed = false;
-
-    /**
-     * @var integer
+     * @var int
      */
     protected $timeoutForSmallTests = 1;
 
     /**
-     * @var integer
+     * @var int
      */
     protected $timeoutForMediumTests = 10;
 
     /**
-     * @var integer
+     * @var int
      */
     protected $timeoutForLargeTests = 60;
 
+    /**
+     * @var bool
+     */
+    protected $stopOnRisky = false;
+
+    /**
+     * @var bool
+     */
+    protected $stopOnIncomplete = false;
+
+    /**
+     * @var bool
+     */
+    protected $stopOnSkipped = false;
+
+    /**
+     * @var bool
+     */
+    protected $lastTestFailed = false;
+
     /**
      * Registers a TestListener.
      *
@@ -230,34 +206,34 @@ class PHPUnit_Framework_TestResult implements Countable
      * Adds an error to the list of errors.
      *
      * @param PHPUnit_Framework_Test $test
-     * @param Exception              $e
+     * @param Throwable              $t
      * @param float                  $time
      */
-    public function addError(PHPUnit_Framework_Test $test, Exception $e, $time)
+    public function addError(PHPUnit_Framework_Test $test, $t, $time)
     {
-        if ($e instanceof PHPUnit_Framework_RiskyTest) {
-            $this->risky[] = new PHPUnit_Framework_TestFailure($test, $e);
+        if ($t instanceof PHPUnit_Framework_RiskyTest) {
+            $this->risky[] = new PHPUnit_Framework_TestFailure($test, $t);
             $notifyMethod  = 'addRiskyTest';
 
             if ($this->stopOnRisky) {
                 $this->stop();
             }
-        } elseif ($e instanceof PHPUnit_Framework_IncompleteTest) {
-            $this->notImplemented[] = new PHPUnit_Framework_TestFailure($test, $e);
+        } elseif ($t instanceof PHPUnit_Framework_IncompleteTest) {
+            $this->notImplemented[] = new PHPUnit_Framework_TestFailure($test, $t);
             $notifyMethod           = 'addIncompleteTest';
 
             if ($this->stopOnIncomplete) {
                 $this->stop();
             }
-        } elseif ($e instanceof PHPUnit_Framework_SkippedTest) {
-            $this->skipped[] = new PHPUnit_Framework_TestFailure($test, $e);
+        } elseif ($t instanceof PHPUnit_Framework_SkippedTest) {
+            $this->skipped[] = new PHPUnit_Framework_TestFailure($test, $t);
             $notifyMethod    = 'addSkippedTest';
 
             if ($this->stopOnSkipped) {
                 $this->stop();
             }
         } else {
-            $this->errors[] = new PHPUnit_Framework_TestFailure($test, $e);
+            $this->errors[] = new PHPUnit_Framework_TestFailure($test, $t);
             $notifyMethod   = 'addError';
 
             if ($this->stopOnError || $this->stopOnFailure) {
@@ -265,14 +241,48 @@ class PHPUnit_Framework_TestResult implements Countable
             }
         }
 
+        // @see https://github.com/sebastianbergmann/phpunit/issues/1953
+        if ($t instanceof Error) {
+            $t = new PHPUnit_Framework_ExceptionWrapper($t);
+        }
+
         foreach ($this->listeners as $listener) {
-            $listener->$notifyMethod($test, $e, $time);
+            $listener->$notifyMethod($test, $t, $time);
         }
 
         $this->lastTestFailed = true;
         $this->time          += $time;
     }
 
+    /**
+     * Adds a warning to the list of warnings.
+     * The passed in exception caused the warning.
+     *
+     * @param PHPUnit_Framework_Test    $test
+     * @param PHPUnit_Framework_Warning $e
+     * @param float                     $time
+     *
+     * @since Method available since Release 5.1.0
+     */
+    public function addWarning(PHPUnit_Framework_Test $test, PHPUnit_Framework_Warning $e, $time)
+    {
+        if ($this->stopOnWarning) {
+            $this->stop();
+        }
+
+        $this->warnings[] = new PHPUnit_Framework_TestFailure($test, $e);
+
+        foreach ($this->listeners as $listener) {
+            // @todo Remove check for PHPUnit 6.0.0
+            // @see  https://github.com/sebastianbergmann/phpunit/pull/1840#issuecomment-162535997
+            if (method_exists($listener, 'addWarning')) {
+                $listener->addWarning($test, $e, $time);
+            }
+        }
+
+        $this->time += $time;
+    }
+
     /**
      * Adds a failure to the list of failures.
      * The passed in exception caused the failure.
@@ -283,7 +293,8 @@ class PHPUnit_Framework_TestResult implements Countable
      */
     public function addFailure(PHPUnit_Framework_Test $test, PHPUnit_Framework_AssertionFailedError $e, $time)
     {
-        if ($e instanceof PHPUnit_Framework_RiskyTest) {
+        if ($e instanceof PHPUnit_Framework_RiskyTest ||
+            $e instanceof PHPUnit_Framework_OutputError) {
             $this->risky[] = new PHPUnit_Framework_TestFailure($test, $e);
             $notifyMethod  = 'addRiskyTest';
 
@@ -325,6 +336,7 @@ class PHPUnit_Framework_TestResult implements Countable
      * Informs the result that a testsuite will be started.
      *
      * @param PHPUnit_Framework_TestSuite $suite
+     *
      * @since  Method available since Release 2.2.0
      */
     public function startTestSuite(PHPUnit_Framework_TestSuite $suite)
@@ -342,6 +354,7 @@ class PHPUnit_Framework_TestResult implements Countable
      * Informs the result that a testsuite was completed.
      *
      * @param PHPUnit_Framework_TestSuite $suite
+     *
      * @since  Method available since Release 2.2.0
      */
     public function endTestSuite(PHPUnit_Framework_TestSuite $suite)
@@ -380,15 +393,15 @@ class PHPUnit_Framework_TestResult implements Countable
 
         if (!$this->lastTestFailed && $test instanceof PHPUnit_Framework_TestCase) {
             $class  = get_class($test);
-            $key    =  $class . '::' . $test->getName();
+            $key    = $class . '::' . $test->getName();
 
-            $this->passed[$key] = array(
-              'result' => $test->getResult(),
-              'size'   => PHPUnit_Util_Test::getSize(
-                  $class,
-                  $test->getName(false)
-              )
-            );
+            $this->passed[$key] = [
+                'result' => $test->getResult(),
+                'size'   => PHPUnit_Util_Test::getSize(
+                    $class,
+                    $test->getName(false)
+                )
+            ];
 
             $this->time += $time;
         }
@@ -397,7 +410,8 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Returns true if no risky test occurred.
      *
-     * @return boolean
+     * @return bool
+     *
      * @since  Method available since Release 4.0.0
      */
     public function allHarmless()
@@ -408,7 +422,8 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Gets the number of risky tests.
      *
-     * @return integer
+     * @return int
+     *
      * @since  Method available since Release 4.0.0
      */
     public function riskyCount()
@@ -419,7 +434,7 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Returns true if no incomplete test occurred.
      *
-     * @return boolean
+     * @return bool
      */
     public function allCompletelyImplemented()
     {
@@ -429,7 +444,7 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Gets the number of incomplete tests.
      *
-     * @return integer
+     * @return int
      */
     public function notImplementedCount()
     {
@@ -440,6 +455,7 @@ class PHPUnit_Framework_TestResult implements Countable
      * Returns an Enumeration for the risky tests.
      *
      * @return array
+     *
      * @since  Method available since Release 4.0.0
      */
     public function risky()
@@ -460,7 +476,8 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Returns true if no test has been skipped.
      *
-     * @return boolean
+     * @return bool
+     *
      * @since  Method available since Release 3.0.0
      */
     public function noneSkipped()
@@ -471,7 +488,8 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Gets the number of skipped tests.
      *
-     * @return integer
+     * @return int
+     *
      * @since  Method available since Release 3.0.0
      */
     public function skippedCount()
@@ -483,6 +501,7 @@ class PHPUnit_Framework_TestResult implements Countable
      * Returns an Enumeration for the skipped tests.
      *
      * @return array
+     *
      * @since  Method available since Release 3.0.0
      */
     public function skipped()
@@ -493,7 +512,7 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Gets the number of detected errors.
      *
-     * @return integer
+     * @return int
      */
     public function errorCount()
     {
@@ -513,7 +532,7 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Gets the number of detected failures.
      *
-     * @return integer
+     * @return int
      */
     public function failureCount()
     {
@@ -530,10 +549,35 @@ class PHPUnit_Framework_TestResult implements Countable
         return $this->failures;
     }
 
+    /**
+     * Gets the number of detected warnings.
+     *
+     * @return int
+     *
+     * @since  Method available since Release 5.1.0
+     */
+    public function warningCount()
+    {
+        return count($this->warnings);
+    }
+
+    /**
+     * Returns an Enumeration for the warnings.
+     *
+     * @return array
+     *
+     * @since  Method available since Release 5.1.0
+     */
+    public function warnings()
+    {
+        return $this->warnings;
+    }
+
     /**
      * Returns the names of the tests that have passed.
      *
      * @return array
+     *
      * @since  Method available since Release 3.4.0
      */
     public function passed()
@@ -545,6 +589,7 @@ class PHPUnit_Framework_TestResult implements Countable
      * Returns the (top) test suite.
      *
      * @return PHPUnit_Framework_TestSuite
+     *
      * @since  Method available since Release 3.0.0
      */
     public function topTestSuite()
@@ -555,7 +600,8 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Returns whether code coverage information should be collected.
      *
-     * @return boolean If code coverage should be collected
+     * @return bool If code coverage should be collected
+     *
      * @since  Method available since Release 3.2.0
      */
     public function getCollectCodeCoverageInformation()
@@ -574,6 +620,7 @@ class PHPUnit_Framework_TestResult implements Countable
 
         $error      = false;
         $failure    = false;
+        $warning    = false;
         $incomplete = false;
         $risky      = false;
         $skipped    = false;
@@ -584,7 +631,7 @@ class PHPUnit_Framework_TestResult implements Countable
 
         if ($this->convertErrorsToExceptions) {
             $oldErrorHandler = set_error_handler(
-                array('PHPUnit_Util_ErrorHandler', 'handleError'),
+                ['PHPUnit_Util_ErrorHandler', 'handleError'],
                 E_ALL | E_STRICT
             );
 
@@ -596,49 +643,44 @@ class PHPUnit_Framework_TestResult implements Countable
         }
 
         $collectCodeCoverage = $this->codeCoverage !== null &&
-                               !$test instanceof PHPUnit_Extensions_SeleniumTestCase &&
-                               !$test instanceof PHPUnit_Framework_Warning;
+                               !$test instanceof PHPUnit_Framework_WarningTestCase;
 
         if ($collectCodeCoverage) {
-            // We need to blacklist test source files when no whitelist is used.
-            if (!$this->codeCoverage->filter()->hasWhitelist()) {
-                $classes = $this->getHierarchy(get_class($test), true);
-
-                foreach ($classes as $class) {
-                    $this->codeCoverage->filter()->addFileToBlacklist(
-                        $class->getFileName()
-                    );
-                }
-            }
-
             $this->codeCoverage->start($test);
         }
 
+        $monitorFunctions = $this->beStrictAboutResourceUsageDuringSmallTests &&
+                            !$test instanceof PHPUnit_Framework_WarningTestCase &&
+                            $test->getSize() == PHPUnit_Util_Test::SMALL &&
+                            function_exists('xdebug_start_function_monitor');
+
+        if ($monitorFunctions) {
+            xdebug_start_function_monitor(ResourceOperations::getFunctions());
+        }
+
         PHP_Timer::start();
 
         try {
-            if (!$test instanceof PHPUnit_Framework_Warning &&
-                $this->beStrictAboutTestSize &&
+            if (!$test instanceof PHPUnit_Framework_WarningTestCase &&
+                $test->getSize() != PHPUnit_Util_Test::UNKNOWN &&
+                $this->enforceTimeLimit &&
                 extension_loaded('pcntl') && class_exists('PHP_Invoker')) {
                 switch ($test->getSize()) {
-                    case PHPUnit_Util_Test::SMALL: {
+                    case PHPUnit_Util_Test::SMALL:
                         $_timeout = $this->timeoutForSmallTests;
-                        }
-                    break;
+                        break;
 
-                    case PHPUnit_Util_Test::MEDIUM: {
+                    case PHPUnit_Util_Test::MEDIUM:
                         $_timeout = $this->timeoutForMediumTests;
-                        }
-                    break;
+                        break;
 
-                    case PHPUnit_Util_Test::LARGE: {
+                    case PHPUnit_Util_Test::LARGE:
                         $_timeout = $this->timeoutForLargeTests;
-                        }
-                    break;
+                        break;
                 }
 
                 $invoker = new PHP_Invoker;
-                $invoker->invoke(array($test, 'runBare'), array(), $_timeout);
+                $invoker->invoke([$test, 'runBare'], [], $_timeout);
             } else {
                 $test->runBare();
             }
@@ -652,13 +694,44 @@ class PHPUnit_Framework_TestResult implements Countable
             } elseif ($e instanceof PHPUnit_Framework_SkippedTestError) {
                 $skipped = true;
             }
+        } catch (PHPUnit_Framework_Warning $e) {
+            $warning = true;
+        } catch (PHPUnit_Framework_Exception $e) {
+            $error = true;
+        } catch (Throwable $e) {
+            $e     = new PHPUnit_Framework_ExceptionWrapper($e);
+            $error = true;
         } catch (Exception $e) {
+            $e     = new PHPUnit_Framework_ExceptionWrapper($e);
             $error = true;
         }
 
         $time = PHP_Timer::stop();
         $test->addToAssertionCount(PHPUnit_Framework_Assert::getCount());
 
+        if ($monitorFunctions) {
+            $blacklist = new PHPUnit_Util_Blacklist;
+            $functions = xdebug_get_monitored_functions();
+            xdebug_stop_function_monitor();
+
+            foreach ($functions as $function) {
+                if (!$blacklist->isBlacklisted($function['filename'])) {
+                    $this->addFailure(
+                        $test,
+                        new PHPUnit_Framework_RiskyTestError(
+                            sprintf(
+                                '%s() used in %s:%s',
+                                $function['function'],
+                                $function['filename'],
+                                $function['lineno']
+                            )
+                        ),
+                        $time
+                    );
+                }
+            }
+        }
+
         if ($this->beStrictAboutTestsThatDoNotTestAnything &&
             $test->getNumAssertions() == 0) {
             $risky = true;
@@ -666,8 +739,8 @@ class PHPUnit_Framework_TestResult implements Countable
 
         if ($collectCodeCoverage) {
             $append           = !$risky && !$incomplete && !$skipped;
-            $linesToBeCovered = array();
-            $linesToBeUsed    = array();
+            $linesToBeCovered = [];
+            $linesToBeUsed    = [];
 
             if ($append && $test instanceof PHPUnit_Framework_TestCase) {
                 $linesToBeCovered = PHPUnit_Util_Test::getLinesToBeCovered(
@@ -687,7 +760,7 @@ class PHPUnit_Framework_TestResult implements Countable
                     $linesToBeCovered,
                     $linesToBeUsed
                 );
-            } catch (PHP_CodeCoverage_Exception_UnintentionallyCoveredCode $cce) {
+            } catch (PHP_CodeCoverage_UnintentionallyCoveredCodeException $cce) {
                 $this->addFailure(
                     $test,
                     new PHPUnit_Framework_UnintentionallyCoveredCodeError(
@@ -717,24 +790,12 @@ class PHPUnit_Framework_TestResult implements Countable
             restore_error_handler();
         }
 
-        if ($this->beStrictAboutTodoAnnotatedTests && $test instanceof PHPUnit_Framework_TestCase) {
-            $annotations = $test->getAnnotations();
-
-            if (isset($annotations['method']['todo'])) {
-                $this->addFailure(
-                    $test,
-                    new PHPUnit_Framework_RiskyTestError(
-                        'Test method is annotated with @todo'
-                    ),
-                    $time
-                );
-            }
-        }
-
         if ($error === true) {
             $this->addError($test, $e, $time);
         } elseif ($failure === true) {
             $this->addFailure($test, $e, $time);
+        } elseif ($warning === true) {
+            $this->addWarning($test, $e, $time);
         } elseif ($this->beStrictAboutTestsThatDoNotTestAnything &&
                  $test->getNumAssertions() == 0) {
             $this->addFailure(
@@ -755,6 +816,18 @@ class PHPUnit_Framework_TestResult implements Countable
                 ),
                 $time
             );
+        } elseif ($this->beStrictAboutTodoAnnotatedTests && $test instanceof PHPUnit_Framework_TestCase) {
+            $annotations = $test->getAnnotations();
+
+            if (isset($annotations['method']['todo'])) {
+                $this->addFailure(
+                    $test,
+                    new PHPUnit_Framework_RiskyTestError(
+                        'Test method is annotated with @todo'
+                    ),
+                    $time
+                );
+            }
         }
 
         $this->endTest($test, $time);
@@ -763,7 +836,7 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Gets the number of run tests.
      *
-     * @return integer
+     * @return int
      */
     public function count()
     {
@@ -773,7 +846,7 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Checks whether the test run should stop.
      *
-     * @return boolean
+     * @return bool
      */
     public function shouldStop()
     {
@@ -782,7 +855,6 @@ class PHPUnit_Framework_TestResult implements Countable
 
     /**
      * Marks that the test run should stop.
-     *
      */
     public function stop()
     {
@@ -793,6 +865,7 @@ class PHPUnit_Framework_TestResult implements Countable
      * Returns the PHP_CodeCoverage object.
      *
      * @return PHP_CodeCoverage
+     *
      * @since  Method available since Release 3.5.0
      */
     public function getCodeCoverage()
@@ -804,6 +877,7 @@ class PHPUnit_Framework_TestResult implements Countable
      * Sets the PHP_CodeCoverage object.
      *
      * @param PHP_CodeCoverage $codeCoverage
+     *
      * @since Method available since Release 3.6.0
      */
     public function setCodeCoverage(PHP_CodeCoverage $codeCoverage)
@@ -814,8 +888,10 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Enables or disables the error-to-exception conversion.
      *
-     * @param  boolean                     $flag
+     * @param bool $flag
+     *
      * @throws PHPUnit_Framework_Exception
+     *
      * @since  Method available since Release 3.2.14
      */
     public function convertErrorsToExceptions($flag)
@@ -830,7 +906,8 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Returns the error-to-exception conversion setting.
      *
-     * @return boolean
+     * @return bool
+     *
      * @since  Method available since Release 3.4.0
      */
     public function getConvertErrorsToExceptions()
@@ -841,8 +918,10 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Enables or disables the stopping when an error occurs.
      *
-     * @param  boolean                     $flag
+     * @param bool $flag
+     *
      * @throws PHPUnit_Framework_Exception
+     *
      * @since  Method available since Release 3.5.0
      */
     public function stopOnError($flag)
@@ -857,8 +936,10 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Enables or disables the stopping when a failure occurs.
      *
-     * @param  boolean                     $flag
+     * @param bool $flag
+     *
      * @throws PHPUnit_Framework_Exception
+     *
      * @since  Method available since Release 3.1.0
      */
     public function stopOnFailure($flag)
@@ -871,8 +952,28 @@ class PHPUnit_Framework_TestResult implements Countable
     }
 
     /**
-     * @param  boolean                     $flag
+     * Enables or disables the stopping when a warning occurs.
+     *
+     * @param bool $flag
+     *
      * @throws PHPUnit_Framework_Exception
+     *
+     * @since  Method available since Release 5.1.0
+     */
+    public function stopOnWarning($flag)
+    {
+        if (!is_bool($flag)) {
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'boolean');
+        }
+
+        $this->stopOnWarning = $flag;
+    }
+
+    /**
+     * @param bool $flag
+     *
+     * @throws PHPUnit_Framework_Exception
+     *
      * @since  Method available since Release 4.0.0
      */
     public function beStrictAboutTestsThatDoNotTestAnything($flag)
@@ -885,7 +986,8 @@ class PHPUnit_Framework_TestResult implements Countable
     }
 
     /**
-     * @return boolean
+     * @return bool
+     *
      * @since  Method available since Release 4.0.0
      */
     public function isStrictAboutTestsThatDoNotTestAnything()
@@ -894,8 +996,10 @@ class PHPUnit_Framework_TestResult implements Countable
     }
 
     /**
-     * @param  boolean                     $flag
+     * @param bool $flag
+     *
      * @throws PHPUnit_Framework_Exception
+     *
      * @since  Method available since Release 4.0.0
      */
     public function beStrictAboutOutputDuringTests($flag)
@@ -908,7 +1012,8 @@ class PHPUnit_Framework_TestResult implements Countable
     }
 
     /**
-     * @return boolean
+     * @return bool
+     *
      * @since  Method available since Release 4.0.0
      */
     public function isStrictAboutOutputDuringTests()
@@ -917,31 +1022,62 @@ class PHPUnit_Framework_TestResult implements Countable
     }
 
     /**
-     * @param  boolean                     $flag
+     * @param bool $flag
+     *
      * @throws PHPUnit_Framework_Exception
-     * @since  Method available since Release 4.0.0
+     *
+     * @since  Method available since Release 5.0.0
      */
-    public function beStrictAboutTestSize($flag)
+    public function beStrictAboutResourceUsageDuringSmallTests($flag)
     {
         if (!is_bool($flag)) {
             throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'boolean');
         }
 
-        $this->beStrictAboutTestSize = $flag;
+        $this->beStrictAboutResourceUsageDuringSmallTests = $flag;
     }
 
     /**
-     * @return boolean
-     * @since  Method available since Release 4.0.0
+     * @return bool
+     *
+     * @since  Method available since Release 5.0.0
      */
-    public function isStrictAboutTestSize()
+    public function isStrictAboutResourceUsageDuringSmallTests()
     {
-        return $this->beStrictAboutTestSize;
+        return $this->beStrictAboutResourceUsageDuringSmallTests;
     }
 
     /**
-     * @param  boolean                     $flag
+     * @param bool $flag
+     *
      * @throws PHPUnit_Framework_Exception
+     *
+     * @since  Method available since Release 5.0.0
+     */
+    public function enforceTimeLimit($flag)
+    {
+        if (!is_bool($flag)) {
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'boolean');
+        }
+
+        $this->enforceTimeLimit = $flag;
+    }
+
+    /**
+     * @return bool
+     *
+     * @since  Method available since Release 5.0.0
+     */
+    public function enforcesTimeLimit()
+    {
+        return $this->enforceTimeLimit;
+    }
+
+    /**
+     * @param bool $flag
+     *
+     * @throws PHPUnit_Framework_Exception
+     *
      * @since  Method available since Release 4.2.0
      */
     public function beStrictAboutTodoAnnotatedTests($flag)
@@ -954,7 +1090,8 @@ class PHPUnit_Framework_TestResult implements Countable
     }
 
     /**
-     * @return boolean
+     * @return bool
+     *
      * @since  Method available since Release 4.2.0
      */
     public function isStrictAboutTodoAnnotatedTests()
@@ -965,8 +1102,10 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Enables or disables the stopping for risky tests.
      *
-     * @param  boolean                     $flag
+     * @param bool $flag
+     *
      * @throws PHPUnit_Framework_Exception
+     *
      * @since  Method available since Release 4.0.0
      */
     public function stopOnRisky($flag)
@@ -981,8 +1120,10 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Enables or disables the stopping for incomplete tests.
      *
-     * @param  boolean                     $flag
+     * @param bool $flag
+     *
      * @throws PHPUnit_Framework_Exception
+     *
      * @since  Method available since Release 3.5.0
      */
     public function stopOnIncomplete($flag)
@@ -997,8 +1138,10 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Enables or disables the stopping for skipped tests.
      *
-     * @param  boolean                     $flag
+     * @param bool $flag
+     *
      * @throws PHPUnit_Framework_Exception
+     *
      * @since  Method available since Release 3.1.0
      */
     public function stopOnSkipped($flag)
@@ -1023,18 +1166,20 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Returns whether the entire test was successful or not.
      *
-     * @return boolean
+     * @return bool
      */
     public function wasSuccessful()
     {
-        return empty($this->errors) && empty($this->failures);
+        return empty($this->errors) && empty($this->failures) && empty($this->warnings);
     }
 
     /**
      * Sets the timeout for small tests.
      *
-     * @param  integer                     $timeout
+     * @param int $timeout
+     *
      * @throws PHPUnit_Framework_Exception
+     *
      * @since  Method available since Release 3.6.0
      */
     public function setTimeoutForSmallTests($timeout)
@@ -1049,8 +1194,10 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Sets the timeout for medium tests.
      *
-     * @param  integer                     $timeout
+     * @param int $timeout
+     *
      * @throws PHPUnit_Framework_Exception
+     *
      * @since  Method available since Release 3.6.0
      */
     public function setTimeoutForMediumTests($timeout)
@@ -1065,8 +1212,10 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Sets the timeout for large tests.
      *
-     * @param  integer                     $timeout
+     * @param int $timeout
+     *
      * @throws PHPUnit_Framework_Exception
+     *
      * @since  Method available since Release 3.6.0
      */
     public function setTimeoutForLargeTests($timeout)
@@ -1081,16 +1230,17 @@ class PHPUnit_Framework_TestResult implements Countable
     /**
      * Returns the class hierarchy for a given class.
      *
-     * @param  string  $className
-     * @param  boolean $asReflectionObjects
+     * @param string $className
+     * @param bool   $asReflectionObjects
+     *
      * @return array
      */
     protected function getHierarchy($className, $asReflectionObjects = false)
     {
         if ($asReflectionObjects) {
-            $classes = array(new ReflectionClass($className));
+            $classes = [new ReflectionClass($className)];
         } else {
-            $classes = array($className);
+            $classes = [$className];
         }
 
         $done = false;
@@ -1098,10 +1248,10 @@ class PHPUnit_Framework_TestResult implements Countable
         while (!$done) {
             if ($asReflectionObjects) {
                 $class = new ReflectionClass(
-                    $classes[count($classes)-1]->getName()
+                    $classes[count($classes) - 1]->getName()
                 );
             } else {
-                $class = new ReflectionClass($classes[count($classes)-1]);
+                $class = new ReflectionClass($classes[count($classes) - 1]);
             }
 
             $parent = $class->getParentClass();
