@@ -30,13 +30,23 @@ class PHPUnit_Runner_Version
         }
 
         if (self::$version === null) {
-            $version       = new SebastianBergmann\Version('4.7.6', dirname(dirname(__DIR__)));
+            $version       = new SebastianBergmann\Version('5.1.3', dirname(dirname(__DIR__)));
             self::$version = $version->getVersion();
         }
 
         return self::$version;
     }
 
+    /**
+     * @return string
+     *
+     * @since Method available since Release 4.8.13
+     */
+    public static function series()
+    {
+        return implode('.', array_slice(explode('.', self::id()), 0, 2));
+    }
+
     /**
      * @return string
      */
@@ -47,6 +57,7 @@ class PHPUnit_Runner_Version
 
     /**
      * @return string
+     *
      * @since  Method available since Release 4.0.0
      */
     public static function getReleaseChannel()
