@@ -19,70 +19,77 @@ class PHPUnit_TextUI_Command
     /**
      * @var array
      */
-    protected $arguments = array(
+    protected $arguments = [
         'listGroups'              => false,
         'loader'                  => null,
         'useDefaultConfiguration' => true
-    );
+    ];
 
     /**
      * @var array
      */
-    protected $options = array();
+    protected $options = [];
 
     /**
      * @var array
      */
-    protected $longOptions = array(
-        'colors=='             => null,
-        'bootstrap='           => null,
-        'columns='             => null,
-        'configuration='       => null,
-        'coverage-clover='     => null,
-        'coverage-crap4j='     => null,
-        'coverage-html='       => null,
-        'coverage-php='        => null,
-        'coverage-text=='      => null,
-        'coverage-xml='        => null,
-        'debug'                => null,
-        'exclude-group='       => null,
-        'filter='              => null,
-        'testsuite='           => null,
-        'group='               => null,
-        'help'                 => null,
-        'include-path='        => null,
-        'list-groups'          => null,
-        'loader='              => null,
-        'log-json='            => null,
-        'log-junit='           => null,
-        'log-tap='             => null,
-        'process-isolation'    => null,
-        'repeat='              => null,
-        'stderr'               => null,
-        'stop-on-error'        => null,
-        'stop-on-failure'      => null,
-        'stop-on-incomplete'   => null,
-        'stop-on-risky'        => null,
-        'stop-on-skipped'      => null,
-        'report-useless-tests' => null,
-        'strict-coverage'      => null,
-        'disallow-test-output' => null,
-        'enforce-time-limit'   => null,
-        'disallow-todo-tests'  => null,
-        'strict-global-state'  => null,
-        'strict'               => null,
-        'tap'                  => null,
-        'testdox'              => null,
-        'testdox-html='        => null,
-        'testdox-text='        => null,
-        'test-suffix='         => null,
-        'no-configuration'     => null,
-        'no-globals-backup'    => null,
-        'printer='             => null,
-        'static-backup'        => null,
-        'verbose'              => null,
-        'version'              => null
-    );
+    protected $longOptions = [
+        'atleast-version='        => null,
+        'bootstrap='              => null,
+        'colors=='                => null,
+        'columns='                => null,
+        'configuration='          => null,
+        'coverage-clover='        => null,
+        'coverage-crap4j='        => null,
+        'coverage-html='          => null,
+        'coverage-php='           => null,
+        'coverage-text=='         => null,
+        'coverage-xml='           => null,
+        'debug'                   => null,
+        'disallow-test-output'    => null,
+        'disallow-resource-usage' => null,
+        'disallow-todo-tests'     => null,
+        'enforce-time-limit'      => null,
+        'exclude-group='          => null,
+        'filter='                 => null,
+        'group='                  => null,
+        'help'                    => null,
+        'include-path='           => null,
+        'list-groups'             => null,
+        'loader='                 => null,
+        'log-json='               => null,
+        'log-junit='              => null,
+        'log-tap='                => null,
+        'log-teamcity='           => null,
+        'no-configuration'        => null,
+        'no-coverage'             => null,
+        'no-globals-backup'       => null,
+        'printer='                => null,
+        'process-isolation'       => null,
+        'repeat='                 => null,
+        'report-useless-tests'    => null,
+        'reverse-list'            => null,
+        'static-backup'           => null,
+        'stderr'                  => null,
+        'stop-on-error'           => null,
+        'stop-on-failure'         => null,
+        'stop-on-warning'         => null,
+        'stop-on-incomplete'      => null,
+        'stop-on-risky'           => null,
+        'stop-on-skipped'         => null,
+        'strict-coverage'         => null,
+        'strict-global-state'     => null,
+        'tap'                     => null,
+        'teamcity'                => null,
+        'testdox'                 => null,
+        'testdox-html='           => null,
+        'testdox-text='           => null,
+        'test-suffix='            => null,
+        'testsuite='              => null,
+        'verbose'                 => null,
+        'version'                 => null,
+        'whitelist='              => null
+    ];
 
     /**
      * @var bool
@@ -100,8 +107,9 @@ class PHPUnit_TextUI_Command
     }
 
     /**
-     * @param  array $argv
-     * @param  bool  $exit
+     * @param array $argv
+     * @param bool  $exit
+     *
      * @return int
      */
     public function run(array $argv, $exit = true)
@@ -168,6 +176,7 @@ class PHPUnit_TextUI_Command
      * Create a TestRunner, override in subclasses.
      *
      * @return PHPUnit_TextUI_TestRunner
+     *
      * @since  Method available since Release 3.6.0
      */
     protected function createRunner()
@@ -223,8 +232,11 @@ class PHPUnit_TextUI_Command
     protected function handleArguments(array $argv)
     {
         if (defined('__PHPUNIT_PHAR__')) {
-            $this->longOptions['selfupdate']  = null;
-            $this->longOptions['self-update'] = null;
+            $this->longOptions['check-version'] = null;
+            $this->longOptions['selfupdate']    = null;
+            $this->longOptions['self-update']   = null;
+            $this->longOptions['selfupgrade']   = null;
+            $this->longOptions['self-upgrade']  = null;
         }
 
         try {
@@ -366,6 +378,10 @@ class PHPUnit_TextUI_Command
                     $this->arguments['tapLogfile'] = $option[1];
                     break;
 
+                case '--log-teamcity':
+                    $this->arguments['teamcityLogfile'] = $option[1];
+                    break;
+
                 case '--process-isolation':
                     $this->arguments['processIsolation'] = true;
                     break;
@@ -386,6 +402,10 @@ class PHPUnit_TextUI_Command
                     $this->arguments['stopOnFailure'] = true;
                     break;
 
+                case '--stop-on-warning':
+                    $this->arguments['stopOnWarning'] = true;
+                    break;
+
                 case '--stop-on-incomplete':
                     $this->arguments['stopOnIncomplete'] = true;
                     break;
@@ -402,6 +422,10 @@ class PHPUnit_TextUI_Command
                     $this->arguments['printer'] = 'PHPUnit_Util_Log_TAP';
                     break;
 
+                case '--teamcity':
+                    $this->arguments['printer'] = 'PHPUnit_Util_Log_TeamCity';
+                    break;
+
                 case '--testdox':
                     $this->arguments['printer'] = 'PHPUnit_Util_TestDox_ResultPrinter_Text';
                     break;
@@ -418,6 +442,10 @@ class PHPUnit_TextUI_Command
                     $this->arguments['useDefaultConfiguration'] = false;
                     break;
 
+                case '--no-coverage':
+                    $this->arguments['noCoverage'] = true;
+                    break;
+
                 case '--no-globals-backup':
                     $this->arguments['backupGlobals'] = false;
                     break;
@@ -431,6 +459,13 @@ class PHPUnit_TextUI_Command
                     $this->arguments['verbose'] = true;
                     break;
 
+                case '--atleast-version':
+                    exit(version_compare(PHPUnit_Runner_Version::id(), $option[1], '>=')
+                        ? PHPUnit_TextUI_TestRunner::SUCCESS_EXIT
+                        : PHPUnit_TextUI_TestRunner::FAILURE_EXIT
+                    );
+                    break;
+
                 case '--version':
                     $this->printVersionString();
                     exit(PHPUnit_TextUI_TestRunner::SUCCESS_EXIT);
@@ -445,13 +480,17 @@ class PHPUnit_TextUI_Command
                     break;
 
                 case '--strict-global-state':
-                    $this->arguments['disallowChangesToGlobalState'] = true;
+                    $this->arguments['beStrictAboutChangesToGlobalState'] = true;
                     break;
 
                 case '--disallow-test-output':
                     $this->arguments['disallowTestOutput'] = true;
                     break;
 
+                case '--disallow-resource-usage':
+                    $this->arguments['beStrictAboutResourceUsageDuringSmallTests'] = true;
+                    break;
+
                 case '--enforce-time-limit':
                     $this->arguments['enforceTimeLimit'] = true;
                     break;
@@ -460,13 +499,12 @@ class PHPUnit_TextUI_Command
                     $this->arguments['disallowTodoAnnotatedTests'] = true;
                     break;
 
-                case '--strict':
-                    $this->arguments['reportUselessTests']         = true;
-                    $this->arguments['strictCoverage']             = true;
-                    $this->arguments['disallowTestOutput']         = true;
-                    $this->arguments['enforceTimeLimit']           = true;
-                    $this->arguments['disallowTodoAnnotatedTests'] = true;
-                    $this->arguments['deprecatedStrictModeOption'] = true;
+                case '--reverse-list':
+                    $this->arguments['reverseList'] = true;
+                    break;
+
+                case '--check-version':
+                    $this->handleVersionCheck();
                     break;
 
                 case '--selfupdate':
@@ -474,6 +512,15 @@ class PHPUnit_TextUI_Command
                     $this->handleSelfUpdate();
                     break;
 
+                case '--selfupgrade':
+                case '--self-upgrade':
+                    $this->handleSelfUpdate(true);
+                    break;
+
+                case '--whitelist':
+                    $this->arguments['whitelist'] = $option[1];
+                    break;
+
                 default:
                     $optionName = str_replace('--', '', $option[0]);
 
@@ -483,7 +530,7 @@ class PHPUnit_TextUI_Command
                         $handler = $this->longOptions[$optionName . '='];
                     }
 
-                    if (isset($handler) && is_callable(array($this, $handler))) {
+                    if (isset($handler) && is_callable([$this, $handler])) {
                         $this->$handler($option[1]);
                     }
             }
@@ -511,7 +558,7 @@ class PHPUnit_TextUI_Command
         }
 
         if (!isset($this->arguments['testSuffixes'])) {
-            $this->arguments['testSuffixes'] = array('Test.php', '.phpt');
+            $this->arguments['testSuffixes'] = ['Test.php', '.phpt'];
         }
 
         if (isset($includePath)) {
@@ -562,7 +609,7 @@ class PHPUnit_TextUI_Command
                 exit(PHPUnit_TextUI_TestRunner::FAILURE_EXIT);
             }
 
-            $phpunit = $configuration->getPHPUnitConfiguration();
+            $phpunitConfiguration = $configuration->getPHPUnitConfiguration();
 
             $configuration->handlePHPConfiguration();
 
@@ -571,53 +618,47 @@ class PHPUnit_TextUI_Command
              */
             if (isset($this->arguments['bootstrap'])) {
                 $this->handleBootstrap($this->arguments['bootstrap']);
-            } elseif (isset($phpunit['bootstrap'])) {
-                $this->handleBootstrap($phpunit['bootstrap']);
+            } elseif (isset($phpunitConfiguration['bootstrap'])) {
+                $this->handleBootstrap($phpunitConfiguration['bootstrap']);
             }
 
             /*
              * Issue #657
              */
-            if (isset($phpunit['stderr']) && ! isset($this->arguments['stderr'])) {
-                $this->arguments['stderr'] = $phpunit['stderr'];
+            if (isset($phpunitConfiguration['stderr']) && ! isset($this->arguments['stderr'])) {
+                $this->arguments['stderr'] = $phpunitConfiguration['stderr'];
             }
 
-            if (isset($phpunit['printerClass'])) {
-                if (isset($phpunit['printerFile'])) {
-                    $file = $phpunit['printerFile'];
+            if (isset($phpunitConfiguration['columns']) && ! isset($this->arguments['columns'])) {
+                $this->arguments['columns'] = $phpunitConfiguration['columns'];
+            }
+
+            if (!isset($this->arguments['printer']) && isset($phpunitConfiguration['printerClass'])) {
+                if (isset($phpunitConfiguration['printerFile'])) {
+                    $file = $phpunitConfiguration['printerFile'];
                 } else {
                     $file = '';
                 }
 
                 $this->arguments['printer'] = $this->handlePrinter(
-                    $phpunit['printerClass'],
+                    $phpunitConfiguration['printerClass'],
                     $file
                 );
             }
 
-            if (isset($phpunit['testSuiteLoaderClass'])) {
-                if (isset($phpunit['testSuiteLoaderFile'])) {
-                    $file = $phpunit['testSuiteLoaderFile'];
+            if (isset($phpunitConfiguration['testSuiteLoaderClass'])) {
+                if (isset($phpunitConfiguration['testSuiteLoaderFile'])) {
+                    $file = $phpunitConfiguration['testSuiteLoaderFile'];
                 } else {
                     $file = '';
                 }
 
                 $this->arguments['loader'] = $this->handleLoader(
-                    $phpunit['testSuiteLoaderClass'],
+                    $phpunitConfiguration['testSuiteLoaderClass'],
                     $file
                 );
             }
 
-            $browsers = $configuration->getSeleniumBrowserConfiguration();
-
-            if (!empty($browsers)) {
-                $this->arguments['deprecatedSeleniumConfiguration'] = true;
-
-                if (class_exists('PHPUnit_Extensions_SeleniumTestCase')) {
-                    PHPUnit_Extensions_SeleniumTestCase::$browsers = $browsers;
-                }
-            }
-
             if (!isset($this->arguments['test'])) {
                 $testSuite = $configuration->getTestSuiteConfiguration(isset($this->arguments['testsuite']) ? $this->arguments['testsuite'] : null);
 
@@ -651,8 +692,9 @@ class PHPUnit_TextUI_Command
     /**
      * Handles the loading of the PHPUnit_Runner_TestSuiteLoader implementation.
      *
-     * @param  string                         $loaderClass
-     * @param  string                         $loaderFile
+     * @param string $loaderClass
+     * @param string $loaderFile
+     *
      * @return PHPUnit_Runner_TestSuiteLoader
      */
     protected function handleLoader($loaderClass, $loaderFile = '')
@@ -695,8 +737,9 @@ class PHPUnit_TextUI_Command
     /**
      * Handles the loading of the PHPUnit_Util_Printer implementation.
      *
-     * @param  string               $printerClass
-     * @param  string               $printerFile
+     * @param string $printerClass
+     * @param string $printerFile
+     *
      * @return PHPUnit_Util_Printer
      */
     protected function handlePrinter($printerClass, $printerFile = '')
@@ -756,7 +799,7 @@ class PHPUnit_TextUI_Command
     /**
      * @since Method available since Release 4.0.0
      */
-    protected function handleSelfUpdate()
+    protected function handleSelfUpdate($upgrade = false)
     {
         $this->printVersionString();
 
@@ -772,10 +815,22 @@ class PHPUnit_TextUI_Command
             exit(PHPUnit_TextUI_TestRunner::EXCEPTION_EXIT);
         }
 
-        $remoteFilename = sprintf(
-            'https://phar.phpunit.de/phpunit%s.phar',
-            PHPUnit_Runner_Version::getReleaseChannel()
-        );
+        if (!$upgrade) {
+            $remoteFilename = sprintf(
+                'https://phar.phpunit.de/phpunit-%s.phar',
+                file_get_contents(
+                    sprintf(
+                        'https://phar.phpunit.de/latest-version-of/phpunit-%s',
+                        PHPUnit_Runner_Version::series()
+                    )
+                )
+            );
+        } else {
+            $remoteFilename = sprintf(
+                'https://phar.phpunit.de/phpunit%s.phar',
+                PHPUnit_Runner_Version::getReleaseChannel()
+            );
+        }
 
         $tempFilename = tempnam(sys_get_temp_dir(), 'phpunit') . '.phar';
 
@@ -785,18 +840,13 @@ class PHPUnit_TextUI_Command
 
         print 'Updating the PHPUnit PHAR ... ';
 
-        $options = array(
-            'ssl' => array(
+        $options = [
+            'ssl' => [
                 'allow_self_signed' => false,
                 'cafile'            => $caFile,
                 'verify_peer'       => true
-            )
-        );
-
-        if (PHP_VERSION_ID < 50600) {
-            $options['ssl']['CN_match']        = 'phar.phpunit.de';
-            $options['ssl']['SNI_server_name'] = 'phar.phpunit.de';
-        }
+            ]
+        ];
 
         file_put_contents(
             $tempFilename,
@@ -831,6 +881,26 @@ class PHPUnit_TextUI_Command
         exit(PHPUnit_TextUI_TestRunner::SUCCESS_EXIT);
     }
 
+    /**
+     * @since Method available since Release 4.8.0
+     */
+    protected function handleVersionCheck()
+    {
+        $this->printVersionString();
+
+        $latestVersion = file_get_contents('https://phar.phpunit.de/latest-version-of/phpunit');
+        $isOutdated    = version_compare($latestVersion, PHPUnit_Runner_Version::id(), '>');
+
+        if ($isOutdated) {
+            print "You are not using the latest version of PHPUnit.\n";
+            print 'Use "phpunit --self-upgrade" to install PHPUnit ' . $latestVersion . "\n";
+        } else {
+            print "You are using the latest version of PHPUnit.\n";
+        }
+
+        exit(PHPUnit_TextUI_TestRunner::SUCCESS_EXIT);
+    }
+
     /**
      * Show the help message.
      */
@@ -851,14 +921,17 @@ Code Coverage Options:
   --coverage-text=<file>    Generate code coverage report in text format.
                             Default: Standard output.
   --coverage-xml <dir>      Generate code coverage report in PHPUnit XML format.
+  --whitelist <dir>         Whitelist <dir> for code coverage analysis.
 
 Logging Options:
 
   --log-junit <file>        Log test execution in JUnit XML format to file.
   --log-tap <file>          Log test execution in TAP format to file.
+  --log-teamcity <file>     Log test execution in TeamCity format to file.
   --log-json <file>         Log test execution in JSON format.
   --testdox-html <file>     Write agile documentation in HTML format to file.
   --testdox-text <file>     Write agile documentation in Text format to file.
+  --reverse-list            Print defects in reverse order
 
 Test Selection Options:
 
@@ -876,6 +949,7 @@ Test Execution Options:
   --strict-coverage         Be strict about unintentionally covered code.
   --strict-global-state     Be strict about changes to global state
   --disallow-test-output    Be strict about output during tests.
+  --disallow-resource-usage Be strict about resource usage during small tests.
   --enforce-time-limit      Enforce time limit based on test size.
   --disallow-todo-tests     Disallow @todo-annotated tests.
 
@@ -889,6 +963,7 @@ Test Execution Options:
   --stderr                  Write to STDERR instead of STDOUT.
   --stop-on-error           Stop execution upon first error.
   --stop-on-failure         Stop execution upon first error or failure.
+  --stop-on-warning         Stop execution upon first warning.
   --stop-on-risky           Stop execution upon first risky test.
   --stop-on-skipped         Stop execution upon first skipped test.
   --stop-on-incomplete      Stop execution upon first incomplete test.
@@ -898,6 +973,7 @@ Test Execution Options:
   --loader <loader>         TestSuiteLoader implementation to use.
   --repeat <times>          Runs the test(s) repeatedly.
   --tap                     Report test execution progress in TAP format.
+  --teamcity                Report test execution progress in TeamCity format.
   --testdox                 Report test execution progress in TestDox format.
   --printer <printer>       TestListener implementation to use.
 
@@ -906,6 +982,7 @@ Configuration Options:
   --bootstrap <file>        A "bootstrap" PHP file that is run before the tests.
   -c|--configuration <file> Read configuration from XML file.
   --no-configuration        Ignore default configuration file (phpunit.xml).
+  --no-coverage             Ignore code coverage configuration.
   --include-path <path(s)>  Prepend PHP's include_path with given path(s).
   -d key[=value]            Sets a php.ini value.
 
@@ -913,11 +990,14 @@ Miscellaneous Options:
 
   -h|--help                 Prints this usage information.
   --version                 Prints the version and exits.
+  --atleast-version <min>   Checks that version is greater than min and exits.
 
 EOT;
 
         if (defined('__PHPUNIT_PHAR__')) {
-            print "\n  --self-update             Update PHPUnit to the latest version.\n";
+            print "\n  --check-version           Check whether PHPUnit is the latest version.";
+            print "\n  --self-update             Update PHPUnit to the latest version within the same\n                            release series.\n";
+            print "\n  --self-upgrade            Upgrade PHPUnit to the latest version.\n";
         }
     }
 
