@@ -1,89 +1,40 @@
 <?php
-/**
- * PHPUnit
+/*
+ * This file is part of PHPUnit.
  *
- * Copyright (c) 2001-2014, Sebastian Bergmann <sebastian@phpunit.de>.
- * All rights reserved.
+ * (c) Sebastian Bergmann <sebastian@phpunit.de>
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *   * Redistributions of source code must retain the above copyright
- *     notice, this list of conditions and the following disclaimer.
- *
- *   * Redistributions in binary form must reproduce the above copyright
- *     notice, this list of conditions and the following disclaimer in
- *     the documentation and/or other materials provided with the
- *     distribution.
- *
- *   * Neither the name of Sebastian Bergmann nor the names of his
- *     contributors may be used to endorse or promote products derived
- *     from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
- * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- *
- * @package    PHPUnit
- * @subpackage Util
- * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2001-2014 Sebastian Bergmann <sebastian@phpunit.de>
- * @license    http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
- * @link       http://www.phpunit.de/
- * @since      File available since Release 3.0.0
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
  */
 
-if (!function_exists('trait_exists')) {
-    function trait_exists($traitname, $autoload = true)
-    {
-        return false;
-    }
-}
-
 /**
  * Test helpers.
  *
- * @package    PHPUnit
- * @subpackage Util
- * @author     Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright  2001-2014 Sebastian Bergmann <sebastian@phpunit.de>
- * @license    http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
- * @link       http://www.phpunit.de/
- * @since      Class available since Release 3.0.0
+ * @since Class available since Release 3.0.0
  */
 class PHPUnit_Util_Test
 {
     const REGEX_DATA_PROVIDER      = '/@dataProvider\s+([a-zA-Z0-9._:-\\\\x7f-\xff]+)/';
+    const REGEX_TEST_WITH          = '/@testWith\s+/';
     const REGEX_EXPECTED_EXCEPTION = '(@expectedException\s+([:.\w\\\\x7f-\xff]+)(?:[\t ]+(\S*))?(?:[\t ]+(\S*))?\s*$)m';
     const REGEX_REQUIRES_VERSION   = '/@requires\s+(?P<name>PHP(?:Unit)?)\s+(?P<value>[\d\.-]+(dev|(RC|alpha|beta)[\d\.])?)[ \t]*\r?$/m';
     const REGEX_REQUIRES_OS        = '/@requires\s+OS\s+(?P<value>.+?)[ \t]*\r?$/m';
     const REGEX_REQUIRES           = '/@requires\s+(?P<name>function|extension)\s+(?P<value>([^ ]+?))[ \t]*\r?$/m';
 
-    const SMALL  = 0;
-    const MEDIUM = 1;
-    const LARGE  = 2;
+    const UNKNOWN = -1;
+    const SMALL   = 0;
+    const MEDIUM  = 1;
+    const LARGE   = 2;
 
-    private static $annotationCache = array();
+    private static $annotationCache = [];
 
-    private static $templateMethods = array(
-      'setUp', 'assertPreConditions', 'assertPostConditions', 'tearDown'
-    );
-
-    private static $hookMethods = array();
+    private static $hookMethods = [];
 
     /**
-     * @param  PHPUnit_Framework_Test $test
-     * @param  boolean                $asString
+     * @param PHPUnit_Framework_Test $test
+     * @param bool                   $asString
+     *
      * @return mixed
      */
     public static function describe(PHPUnit_Framework_Test $test, $asString = true)
@@ -96,22 +47,25 @@ class PHPUnit_Util_Test
             }
         } else {
             if ($test instanceof PHPUnit_Framework_TestCase) {
-                return array(
+                return [
                   get_class($test), $test->getName()
-                );
+                ];
             } elseif ($test instanceof PHPUnit_Framework_SelfDescribing) {
-                return array('', $test->toString());
+                return ['', $test->toString()];
             } else {
-                return array('', get_class($test));
+                return ['', get_class($test)];
             }
         }
     }
 
     /**
-     * @param  string     $className
-     * @param  string     $methodName
+     * @param string $className
+     * @param string $methodName
+     *
      * @return array|bool
+     *
      * @throws PHPUnit_Framework_CodeCoverageException
+     *
      * @since  Method available since Release 4.0.0
      */
     public static function getLinesToBeCovered($className, $methodName)
@@ -131,9 +85,11 @@ class PHPUnit_Util_Test
     /**
      * Returns lines of code specified with the @uses annotation.
      *
-     * @param  string $className
-     * @param  string $methodName
+     * @param string $className
+     * @param string $methodName
+     *
      * @return array
+     *
      * @since  Method available since Release 4.0.0
      */
     public static function getLinesToBeUsed($className, $methodName)
@@ -142,11 +98,14 @@ class PHPUnit_Util_Test
     }
 
     /**
-     * @param  string $className
-     * @param  string $methodName
-     * @param  string $mode
+     * @param string $className
+     * @param string $methodName
+     * @param string $mode
+     *
      * @return array
+     *
      * @throws PHPUnit_Framework_CodeCoverageException
+     *
      * @since  Method available since Release 4.2.0
      */
     private static function getLinesToBeCoveredOrUsed($className, $methodName, $mode)
@@ -172,7 +131,7 @@ class PHPUnit_Util_Test
             $classShortcut = $annotations['class'][$mode . 'DefaultClass'][0];
         }
 
-        $list = array();
+        $list = [];
 
         if (isset($annotations['class'][$mode])) {
             $list = $annotations['class'][$mode];
@@ -182,7 +141,7 @@ class PHPUnit_Util_Test
             $list = array_merge($list, $annotations['method'][$mode]);
         }
 
-        $codeList = array();
+        $codeList = [];
 
         foreach (array_unique($list) as $element) {
             if ($classShortcut && strncmp($element, '::', 2) === 0) {
@@ -190,6 +149,8 @@ class PHPUnit_Util_Test
             }
 
             $element = preg_replace('/[\s()]+$/', '', $element);
+            $element = explode(' ', $element);
+            $element = $element[0];
 
             $codeList = array_merge(
                 $codeList,
@@ -203,9 +164,11 @@ class PHPUnit_Util_Test
     /**
      * Returns the requirements for a test.
      *
-     * @param  string $className
-     * @param  string $methodName
+     * @param string $className
+     * @param string $methodName
+     *
      * @return array
+     *
      * @since  Method available since Release 3.6.0
      */
     public static function getRequirements($className, $methodName)
@@ -214,7 +177,7 @@ class PHPUnit_Util_Test
         $docComment = $reflector->getDocComment();
         $reflector  = new ReflectionMethod($className, $methodName);
         $docComment .= "\n" . $reflector->getDocComment();
-        $requires   = array();
+        $requires   = [];
 
         if ($count = preg_match_all(self::REGEX_REQUIRES_OS, $docComment, $matches)) {
             $requires['OS'] = sprintf(
@@ -229,13 +192,13 @@ class PHPUnit_Util_Test
         }
 
         // https://bugs.php.net/bug.php?id=63055
-        $matches = array();
+        $matches = [];
 
         if ($count = preg_match_all(self::REGEX_REQUIRES, $docComment, $matches)) {
             for ($i = 0; $i < $count; $i++) {
                 $name = $matches['name'][$i] . 's';
                 if (!isset($requires[$name])) {
-                    $requires[$name] = array();
+                    $requires[$name] = [];
                 }
                 $requires[$name][] = $matches['value'][$i];
             }
@@ -244,12 +207,68 @@ class PHPUnit_Util_Test
         return $requires;
     }
 
+    /**
+     * Returns the missing requirements for a test.
+     *
+     * @param string $className
+     * @param string $methodName
+     *
+     * @return array
+     *
+     * @since  Method available since Release 4.3.0
+     */
+    public static function getMissingRequirements($className, $methodName)
+    {
+        $required = static::getRequirements($className, $methodName);
+        $missing  = [];
+
+        if (!empty($required['PHP']) && version_compare(PHP_VERSION, $required['PHP'], '<')) {
+            $missing[] = sprintf('PHP %s (or later) is required.', $required['PHP']);
+        }
+
+        if (!empty($required['PHPUnit'])) {
+            $phpunitVersion = PHPUnit_Runner_Version::id();
+            if (version_compare($phpunitVersion, $required['PHPUnit'], '<')) {
+                $missing[] = sprintf('PHPUnit %s (or later) is required.', $required['PHPUnit']);
+            }
+        }
+
+        if (!empty($required['OS']) && !preg_match($required['OS'], PHP_OS)) {
+            $missing[] = sprintf('Operating system matching %s is required.', $required['OS']);
+        }
+
+        if (!empty($required['functions'])) {
+            foreach ($required['functions'] as $function) {
+                $pieces = explode('::', $function);
+                if (2 === count($pieces) && method_exists($pieces[0], $pieces[1])) {
+                    continue;
+                }
+                if (function_exists($function)) {
+                    continue;
+                }
+                $missing[] = sprintf('Function %s is required.', $function);
+            }
+        }
+
+        if (!empty($required['extensions'])) {
+            foreach ($required['extensions'] as $extension) {
+                if (!extension_loaded($extension)) {
+                    $missing[] = sprintf('Extension %s is required.', $extension);
+                }
+            }
+        }
+
+        return $missing;
+    }
+
     /**
      * Returns the expected exception for a test.
      *
-     * @param  string $className
-     * @param  string $methodName
+     * @param string $className
+     * @param string $methodName
+     *
      * @return array
+     *
      * @since  Method available since Release 3.3.6
      */
     public static function getExpectedException($className, $methodName)
@@ -264,9 +283,10 @@ class PHPUnit_Util_Test
                 $methodName
             );
 
-            $class   = $matches[1];
-            $code    = null;
-            $message = '';
+            $class         = $matches[1];
+            $code          = null;
+            $message       = '';
+            $messageRegExp = '';
 
             if (isset($matches[2])) {
                 $message = trim($matches[2]);
@@ -276,6 +296,12 @@ class PHPUnit_Util_Test
                 );
             }
 
+            if (isset($annotations['method']['expectedExceptionMessageRegExp'])) {
+                $messageRegExp = self::parseAnnotationContent(
+                    $annotations['method']['expectedExceptionMessageRegExp'][0]
+                );
+            }
+
             if (isset($matches[3])) {
                 $code = $matches[3];
             } elseif (isset($annotations['method']['expectedExceptionCode'])) {
@@ -290,9 +316,9 @@ class PHPUnit_Util_Test
                 $code = (int) constant($code);
             }
 
-            return array(
-              'class' => $class, 'code' => $code, 'message' => $message
-            );
+            return [
+              'class' => $class, 'code' => $code, 'message' => $message, 'message_regex' => $messageRegExp
+            ];
         }
 
         return false;
@@ -305,7 +331,8 @@ class PHPUnit_Util_Test
      *
      * If the constant is not found the string is used as is to ensure maximum BC.
      *
-     * @param  string $message
+     * @param string $message
+     *
      * @return string
      */
     private static function parseAnnotationContent($message)
@@ -322,12 +349,14 @@ class PHPUnit_Util_Test
     /**
      * Returns the provided data for a method.
      *
-     * @param  string           $className
-     * @param  string           $methodName
+     * @param string $className
+     * @param string $methodName
+     *
      * @return array|Iterator when a data provider is specified and exists
-     *         false          when a data provider is specified but does not exist
-     *         null           when no data provider is specified
+     *                        null           when no data provider is specified
+     *
      * @throws PHPUnit_Framework_Exception
+     *
      * @since  Method available since Release 3.2.0
      */
     public static function getProvidedData($className, $methodName)
@@ -336,13 +365,55 @@ class PHPUnit_Util_Test
         $docComment = $reflector->getDocComment();
         $data       = null;
 
+        if ($dataProviderData = self::getDataFromDataProviderAnnotation($docComment, $className, $methodName)) {
+            $data = $dataProviderData;
+        }
+
+        if ($testWithData = self::getDataFromTestWithAnnotation($docComment)) {
+            $data = $testWithData;
+        }
+
+        if ($data !== null) {
+            if (is_object($data)) {
+                $data = iterator_to_array($data);
+            }
+
+            foreach ($data as $key => $value) {
+                if (!is_array($value)) {
+                    throw new PHPUnit_Framework_Exception(
+                        sprintf(
+                            'Data set %s is invalid.',
+                            is_int($key) ? '#' . $key : '"' . $key . '"'
+                        )
+                    );
+                }
+            }
+        }
+
+        return $data;
+    }
+
+    /**
+     * Returns the provided data for a method.
+     *
+     * @param string $docComment
+     * @param string $className
+     * @param string $methodName
+     *
+     * @return array|Iterator when a data provider is specified and exists
+     *                        null           when no data provider is specified
+     *
+     * @throws PHPUnit_Framework_Exception
+     */
+    private static function getDataFromDataProviderAnnotation($docComment, $className, $methodName)
+    {
         if (preg_match(self::REGEX_DATA_PROVIDER, $docComment, $matches)) {
             $dataProviderMethodNameNamespace = explode('\\', $matches[1]);
             $leaf                            = explode('::', array_pop($dataProviderMethodNameNamespace));
             $dataProviderMethodName          = array_pop($leaf);
 
             if (!empty($dataProviderMethodNameNamespace)) {
-                $dataProviderMethodNameNamespace = join('\\', $dataProviderMethodNameNamespace) . '\\';
+                $dataProviderMethodNameNamespace = implode('\\', $dataProviderMethodNameNamespace) . '\\';
             } else {
                 $dataProviderMethodNameNamespace = '';
             }
@@ -369,66 +440,96 @@ class PHPUnit_Util_Test
             } else {
                 $data = $dataProviderMethod->invoke($object, $methodName);
             }
+
+            return $data;
         }
-
-        if ($data !== null) {
-            if (is_object($data)) {
-                $data = iterator_to_array($data);
-            }
-
-            foreach ($data as $key => $value) {
-                if (!is_array($value)) {
-                    throw new PHPUnit_Framework_Exception(
-                        sprintf(
-                            'Data set %s is invalid.',
-                            is_int($key) ? '#' . $key : '"' . $key . '"'
-                        )
-                    );
-                }
-            }
-        }
-
-        return $data;
     }
 
     /**
-     * @param  string              $className
-     * @param  string              $methodName
+     * @param string $docComment full docComment string
+     *
+     * @return array when @testWith annotation is defined
+     *               null  when @testWith annotation is omitted
+     *
+     * @throws PHPUnit_Framework_Exception when @testWith annotation is defined but cannot be parsed
+     */
+    public static function getDataFromTestWithAnnotation($docComment)
+    {
+        $docComment = self::cleanUpMultiLineAnnotation($docComment);
+        if (preg_match(self::REGEX_TEST_WITH, $docComment, $matches, PREG_OFFSET_CAPTURE)) {
+            $offset            = strlen($matches[0][0]) + $matches[0][1];
+            $annotationContent = substr($docComment, $offset);
+            $data              = [];
+            foreach (explode("\n", $annotationContent) as $candidateRow) {
+                $candidateRow = trim($candidateRow);
+                $dataSet      = json_decode($candidateRow, true);
+                if (json_last_error() != JSON_ERROR_NONE) {
+                    break;
+                }
+                $data[] = $dataSet;
+            }
+
+            if (!$data) {
+                throw new PHPUnit_Framework_Exception('The dataset for the @testWith annotation cannot be parsed.');
+            }
+
+            return $data;
+        }
+    }
+
+    private static function cleanUpMultiLineAnnotation($docComment)
+    {
+        //removing initial '   * ' for docComment
+        $docComment = preg_replace('/' . '\n' . '\s*' . '\*' . '\s?' . '/', "\n", $docComment);
+        $docComment = substr($docComment, 0, -1);
+        $docComment = rtrim($docComment, "\n");
+
+        return $docComment;
+    }
+
+    /**
+     * @param string $className
+     * @param string $methodName
+     *
      * @return array
+     *
      * @throws ReflectionException
+     *
      * @since  Method available since Release 3.4.0
      */
     public static function parseTestMethodAnnotations($className, $methodName = '')
     {
         if (!isset(self::$annotationCache[$className])) {
-            $class = new ReflectionClass($className);
+            $class                             = new ReflectionClass($className);
             self::$annotationCache[$className] = self::parseAnnotations($class->getDocComment());
         }
 
         if (!empty($methodName) && !isset(self::$annotationCache[$className . '::' . $methodName])) {
             try {
-                $method = new ReflectionMethod($className, $methodName);
+                $method      = new ReflectionMethod($className, $methodName);
                 $annotations = self::parseAnnotations($method->getDocComment());
             } catch (ReflectionException $e) {
-                $annotations = array();
+                $annotations = [];
             }
             self::$annotationCache[$className . '::' . $methodName] = $annotations;
         }
 
-        return array(
+        return [
           'class'  => self::$annotationCache[$className],
-          'method' => !empty($methodName) ? self::$annotationCache[$className . '::' . $methodName] : array()
-        );
+          'method' => !empty($methodName) ? self::$annotationCache[$className . '::' . $methodName] : []
+        ];
     }
 
     /**
-     * @param  string $docblock
+     * @param string $docblock
+     *
      * @return array
+     *
      * @since  Method available since Release 3.4.0
      */
     private static function parseAnnotations($docblock)
     {
-        $annotations = array();
+        $annotations = [];
         // Strip away the docblock header and footer to ease parsing of one line annotations
         $docblock = substr($docblock, 3, -2);
 
@@ -446,14 +547,16 @@ class PHPUnit_Util_Test
     /**
      * Returns the backup settings for a test.
      *
-     * @param  string $className
-     * @param  string $methodName
+     * @param string $className
+     * @param string $methodName
+     *
      * @return array
+     *
      * @since  Method available since Release 3.4.0
      */
     public static function getBackupSettings($className, $methodName)
     {
-        return array(
+        return [
           'backupGlobals' => self::getBooleanAnnotationSetting(
               $className,
               $methodName,
@@ -464,15 +567,17 @@ class PHPUnit_Util_Test
               $methodName,
               'backupStaticAttributes'
           )
-        );
+        ];
     }
 
     /**
      * Returns the dependencies for a test class or method.
      *
-     * @param  string $className
-     * @param  string $methodName
+     * @param string $className
+     * @param string $methodName
+     *
      * @return array
+     *
      * @since  Method available since Release 3.4.0
      */
     public static function getDependencies($className, $methodName)
@@ -482,7 +587,7 @@ class PHPUnit_Util_Test
             $methodName
         );
 
-        $dependencies = array();
+        $dependencies = [];
 
         if (isset($annotations['class']['depends'])) {
             $dependencies = $annotations['class']['depends'];
@@ -501,9 +606,11 @@ class PHPUnit_Util_Test
     /**
      * Returns the error handler settings for a test.
      *
-     * @param  string  $className
-     * @param  string  $methodName
-     * @return boolean
+     * @param string $className
+     * @param string $methodName
+     *
+     * @return bool
+     *
      * @since  Method available since Release 3.4.0
      */
     public static function getErrorHandlerSettings($className, $methodName)
@@ -518,9 +625,11 @@ class PHPUnit_Util_Test
     /**
      * Returns the groups for a test class or method.
      *
-     * @param  string $className
-     * @param  string $methodName
+     * @param string $className
+     * @param string $methodName
+     *
      * @return array
+     *
      * @since  Method available since Release 3.2.0
      */
     public static function getGroups($className, $methodName = '')
@@ -530,7 +639,7 @@ class PHPUnit_Util_Test
             $methodName
         );
 
-        $groups = array();
+        $groups = [];
 
         if (isset($annotations['method']['author'])) {
             $groups = $annotations['method']['author'];
@@ -554,11 +663,17 @@ class PHPUnit_Util_Test
             $groups = array_merge($groups, $annotations['method']['ticket']);
         }
 
-        foreach (array('small', 'medium', 'large') as $size) {
-            if (isset($annotations['method'][$size])) {
-                $groups[] = $size;
-            } elseif (isset($annotations['class'][$size])) {
-                $groups[] = $size;
+        foreach (['method', 'class'] as $element) {
+            foreach (['small', 'medium', 'large'] as $size) {
+                if (isset($annotations[$element][$size])) {
+                    $groups[] = $size;
+                    break 2;
+                }
+
+                if (isset($annotations[$element][$size])) {
+                    $groups[] = $size;
+                    break 2;
+                }
             }
         }
 
@@ -568,26 +683,27 @@ class PHPUnit_Util_Test
     /**
      * Returns the size of the test.
      *
-     * @param  string  $className
-     * @param  string  $methodName
-     * @return integer
+     * @param string $className
+     * @param string $methodName
+     *
+     * @return int
+     *
      * @since  Method available since Release 3.6.0
      */
     public static function getSize($className, $methodName)
     {
         $groups = array_flip(self::getGroups($className, $methodName));
-        $size   = self::SMALL;
+        $size   = self::UNKNOWN;
         $class  = new ReflectionClass($className);
 
-        if ((class_exists('PHPUnit_Extensions_Database_TestCase', false) &&
-             $class->isSubclassOf('PHPUnit_Extensions_Database_TestCase')) ||
-            (class_exists('PHPUnit_Extensions_SeleniumTestCase', false) &&
-             $class->isSubclassOf('PHPUnit_Extensions_SeleniumTestCase'))) {
+        if (isset($groups['large']) ||
+            (class_exists('PHPUnit_Extensions_Database_TestCase', false) &&
+             $class->isSubclassOf('PHPUnit_Extensions_Database_TestCase'))) {
             $size = self::LARGE;
         } elseif (isset($groups['medium'])) {
             $size = self::MEDIUM;
-        } elseif (isset($groups['large'])) {
-            $size = self::LARGE;
+        } elseif (isset($groups['small'])) {
+            $size = self::SMALL;
         }
 
         return $size;
@@ -596,9 +712,11 @@ class PHPUnit_Util_Test
     /**
      * Returns the tickets for a test class or method.
      *
-     * @param  string $className
-     * @param  string $methodName
+     * @param string $className
+     * @param string $methodName
+     *
      * @return array
+     *
      * @since  Method available since Release 3.4.0
      */
     public static function getTickets($className, $methodName)
@@ -608,7 +726,7 @@ class PHPUnit_Util_Test
             $methodName
         );
 
-        $tickets = array();
+        $tickets = [];
 
         if (isset($annotations['class']['ticket'])) {
             $tickets = $annotations['class']['ticket'];
@@ -624,9 +742,11 @@ class PHPUnit_Util_Test
     /**
      * Returns the process isolation settings for a test.
      *
-     * @param  string  $className
-     * @param  string  $methodName
-     * @return boolean
+     * @param string $className
+     * @param string $methodName
+     *
+     * @return bool
+     *
      * @since  Method available since Release 3.4.1
      */
     public static function getProcessIsolationSettings($className, $methodName)
@@ -647,9 +767,11 @@ class PHPUnit_Util_Test
     /**
      * Returns the preserve global state settings for a test.
      *
-     * @param  string  $className
-     * @param  string  $methodName
-     * @return boolean
+     * @param string $className
+     * @param string $methodName
+     *
+     * @return bool
+     *
      * @since  Method available since Release 3.4.0
      */
     public static function getPreserveGlobalStateSettings($className, $methodName)
@@ -662,8 +784,10 @@ class PHPUnit_Util_Test
     }
 
     /**
-     * @param  string $className
+     * @param string $className
+     *
      * @return array
+     *
      * @since  Method available since Release 4.0.8
      */
     public static function getHookMethods($className)
@@ -679,10 +803,6 @@ class PHPUnit_Util_Test
                 $class = new ReflectionClass($className);
 
                 foreach ($class->getMethods() as $method) {
-                    if ($method->getDeclaringClass()->getName() != $className) {
-                        continue;
-                    }
-
                     if (self::isBeforeClassMethod($method)) {
                         self::$hookMethods[$className]['beforeClass'][] = $method->getName();
                     }
@@ -708,23 +828,26 @@ class PHPUnit_Util_Test
 
     /**
      * @return array
+     *
      * @since  Method available since Release 4.0.9
      */
     private static function emptyHookMethodsArray()
     {
-        return array(
-            'beforeClass' => array('setUpBeforeClass'),
-            'before' => array('setUp'),
-            'after' => array('tearDown'),
-            'afterClass' => array('tearDownAfterClass')
-        );
+        return [
+            'beforeClass' => ['setUpBeforeClass'],
+            'before'      => ['setUp'],
+            'after'       => ['tearDown'],
+            'afterClass'  => ['tearDownAfterClass']
+        ];
     }
 
     /**
-     * @param  string  $className
-     * @param  string  $methodName
-     * @param  string  $settingName
-     * @return boolean
+     * @param string $className
+     * @param string $methodName
+     * @param string $settingName
+     *
+     * @return bool
+     *
      * @since  Method available since Release 3.4.0
      */
     private static function getBooleanAnnotationSetting($className, $methodName, $settingName)
@@ -756,24 +879,30 @@ class PHPUnit_Util_Test
     }
 
     /**
-     * @param  string $element
+     * @param string $element
+     *
      * @return array
+     *
      * @throws PHPUnit_Framework_InvalidCoversTargetException
+     *
      * @since  Method available since Release 4.0.0
      */
     private static function resolveElementToReflectionObjects($element)
     {
-        $codeToCoverList = array();
+        $codeToCoverList = [];
 
-        if (strpos($element, '::') !== false) {
+        if (strpos($element, '\\') !== false && function_exists($element)) {
+            $codeToCoverList[] = new ReflectionFunction($element);
+        } elseif (strpos($element, '::') !== false) {
             list($className, $methodName) = explode('::', $element);
 
             if (isset($methodName[0]) && $methodName[0] == '<') {
-                $classes = array($className);
+                $classes = [$className];
 
                 foreach ($classes as $className) {
                     if (!class_exists($className) &&
-                        !interface_exists($className)) {
+                        !interface_exists($className) &&
+                        !trait_exists($className)) {
                         throw new PHPUnit_Framework_InvalidCoversTargetException(
                             sprintf(
                                 'Trying to @cover or @use not existing class or ' .
@@ -804,7 +933,7 @@ class PHPUnit_Util_Test
                     }
                 }
             } else {
-                $classes = array($className);
+                $classes = [$className];
 
                 foreach ($classes as $className) {
                     if ($className == '' && function_exists($methodName)) {
@@ -840,7 +969,7 @@ class PHPUnit_Util_Test
                 $extended = true;
             }
 
-            $classes = array($element);
+            $classes = [$element];
 
             if ($extended) {
                 $classes = array_merge(
@@ -871,18 +1000,19 @@ class PHPUnit_Util_Test
     }
 
     /**
-     * @param  array $reflectors
+     * @param array $reflectors
+     *
      * @return array
      */
     private static function resolveReflectionObjectsToLines(array $reflectors)
     {
-        $result = array();
+        $result = [];
 
         foreach ($reflectors as $reflector) {
             $filename = $reflector->getFileName();
 
             if (!isset($result[$filename])) {
-                $result[$filename] = array();
+                $result[$filename] = [];
             }
 
             $result[$filename] = array_unique(
@@ -897,8 +1027,10 @@ class PHPUnit_Util_Test
     }
 
     /**
-     * @param  ReflectionMethod $method
-     * @return boolean
+     * @param ReflectionMethod $method
+     *
+     * @return bool
+     *
      * @since  Method available since Release 4.0.8
      */
     private static function isBeforeClassMethod(ReflectionMethod $method)
@@ -907,8 +1039,10 @@ class PHPUnit_Util_Test
     }
 
     /**
-     * @param  ReflectionMethod $method
-     * @return boolean
+     * @param ReflectionMethod $method
+     *
+     * @return bool
+     *
      * @since  Method available since Release 4.0.8
      */
     private static function isBeforeMethod(ReflectionMethod $method)
@@ -917,8 +1051,10 @@ class PHPUnit_Util_Test
     }
 
     /**
-     * @param  ReflectionMethod $method
-     * @return boolean
+     * @param ReflectionMethod $method
+     *
+     * @return bool
+     *
      * @since  Method available since Release 4.0.8
      */
     private static function isAfterClassMethod(ReflectionMethod $method)
@@ -927,8 +1063,10 @@ class PHPUnit_Util_Test
     }
 
     /**
-     * @param  ReflectionMethod $method
-     * @return boolean
+     * @param ReflectionMethod $method
+     *
+     * @return bool
+     *
      * @since  Method available since Release 4.0.8
      */
     private static function isAfterMethod(ReflectionMethod $method)
