@@ -16,6 +16,9 @@ if (!defined('TEST_FILES_PATH')) {
     );
 }
 
+require TEST_FILES_PATH . 'CoverageNamespacedFunctionTest.php';
+require TEST_FILES_PATH . 'NamespaceCoveredFunction.php';
+
 /**
  * @since      Class available since Release 3.3.6
  */
@@ -23,73 +26,74 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
 {
     /**
      * @covers PHPUnit_Util_Test::getExpectedException
+     *
      * @todo   Split up in separate tests
      */
     public function testGetExpectedException()
     {
         $this->assertArraySubset(
-          array('class' => 'FooBarBaz', 'code' => null, 'message' => ''),
+          ['class' => 'FooBarBaz', 'code' => null, 'message' => ''],
           PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testOne')
         );
 
         $this->assertArraySubset(
-          array('class' => 'Foo_Bar_Baz', 'code' => null, 'message' => ''),
+          ['class' => 'Foo_Bar_Baz', 'code' => null, 'message' => ''],
           PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testTwo')
         );
 
         $this->assertArraySubset(
-          array('class' => 'Foo\Bar\Baz', 'code' => null, 'message' => ''),
+          ['class' => 'Foo\Bar\Baz', 'code' => null, 'message' => ''],
           PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testThree')
         );
 
         $this->assertArraySubset(
-          array('class' => 'ほげ', 'code' => null, 'message' => ''),
+          ['class' => 'ほげ', 'code' => null, 'message' => ''],
           PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testFour')
         );
 
         $this->assertArraySubset(
-          array('class' => 'Class', 'code' => 1234, 'message' => 'Message'),
+          ['class' => 'Class', 'code' => 1234, 'message' => 'Message'],
           PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testFive')
         );
 
         $this->assertArraySubset(
-          array('class' => 'Class', 'code' => 1234, 'message' => 'Message'),
+          ['class' => 'Class', 'code' => 1234, 'message' => 'Message'],
           PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testSix')
         );
 
         $this->assertArraySubset(
-          array('class' => 'Class', 'code' => 'ExceptionCode', 'message' => 'Message'),
+          ['class' => 'Class', 'code' => 'ExceptionCode', 'message' => 'Message'],
           PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testSeven')
         );
 
         $this->assertArraySubset(
-          array('class' => 'Class', 'code' => 0, 'message' => 'Message'),
+          ['class' => 'Class', 'code' => 0, 'message' => 'Message'],
           PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testEight')
         );
 
         $this->assertArraySubset(
-          array('class' => 'Class', 'code' => ExceptionTest::ERROR_CODE, 'message' => ExceptionTest::ERROR_MESSAGE),
+          ['class' => 'Class', 'code' => ExceptionTest::ERROR_CODE, 'message' => ExceptionTest::ERROR_MESSAGE],
           PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testNine')
         );
 
         $this->assertArraySubset(
-          array('class' => 'Class', 'code' => null, 'message' => ''),
+          ['class' => 'Class', 'code' => null, 'message' => ''],
           PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testSingleLine')
         );
 
         $this->assertArraySubset(
-          array('class' => 'Class', 'code' => My\Space\ExceptionNamespaceTest::ERROR_CODE, 'message' => My\Space\ExceptionNamespaceTest::ERROR_MESSAGE),
+          ['class' => 'Class', 'code' => My\Space\ExceptionNamespaceTest::ERROR_CODE, 'message' => My\Space\ExceptionNamespaceTest::ERROR_MESSAGE],
           PHPUnit_Util_Test::getExpectedException('My\Space\ExceptionNamespaceTest', 'testConstants')
         );
 
         // Ensure the Class::CONST expression is only evaluated when the constant really exists
         $this->assertArraySubset(
-          array('class' => 'Class', 'code' => 'ExceptionTest::UNKNOWN_CODE_CONSTANT', 'message' => 'ExceptionTest::UNKNOWN_MESSAGE_CONSTANT'),
+          ['class' => 'Class', 'code' => 'ExceptionTest::UNKNOWN_CODE_CONSTANT', 'message' => 'ExceptionTest::UNKNOWN_MESSAGE_CONSTANT'],
           PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testUnknownConstants')
         );
 
         $this->assertArraySubset(
-          array('class' => 'Class', 'code' => 'My\Space\ExceptionNamespaceTest::UNKNOWN_CODE_CONSTANT', 'message' => 'My\Space\ExceptionNamespaceTest::UNKNOWN_MESSAGE_CONSTANT'),
+          ['class' => 'Class', 'code' => 'My\Space\ExceptionNamespaceTest::UNKNOWN_CODE_CONSTANT', 'message' => 'My\Space\ExceptionNamespaceTest::UNKNOWN_MESSAGE_CONSTANT'],
           PHPUnit_Util_Test::getExpectedException('My\Space\ExceptionNamespaceTest', 'testUnknownConstants')
         );
     }
@@ -100,17 +104,17 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
     public function testGetExpectedRegExp()
     {
         $this->assertArraySubset(
-          array('message_regex' => '#regex#'),
+          ['message_regex' => '#regex#'],
           PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testWithRegexMessage')
         );
 
         $this->assertArraySubset(
-          array('message_regex' => '#regex#'),
+          ['message_regex' => '#regex#'],
           PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testWithRegexMessageFromClassConstant')
         );
 
         $this->assertArraySubset(
-          array('message_regex' => 'ExceptionTest::UNKNOWN_MESSAGE_REGEX_CONSTANT'),
+          ['message_regex' => 'ExceptionTest::UNKNOWN_MESSAGE_REGEX_CONSTANT'],
           PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testWithUnknowRegexMessageFromClassConstant')
         );
     }
@@ -129,42 +133,42 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
 
     public function requirementsProvider()
     {
-        return array(
-            array('testOne',    array()),
-            array('testTwo',    array('PHPUnit' => '1.0')),
-            array('testThree',  array('PHP' => '2.0')),
-            array('testFour',   array('PHPUnit'=>'2.0', 'PHP' => '1.0')),
-            array('testFive',   array('PHP' => '5.4.0RC6')),
-            array('testSix',    array('PHP' => '5.4.0-alpha1')),
-            array('testSeven',  array('PHP' => '5.4.0beta2')),
-            array('testEight',  array('PHP' => '5.4-dev')),
-            array('testNine',   array('functions' => array('testFunc'))),
-            array('testTen',    array('extensions' => array('testExt'))),
-            array('testEleven', array('OS' => '/Linux/i')),
-            array(
+        return [
+            ['testOne',    []],
+            ['testTwo',    ['PHPUnit'    => '1.0']],
+            ['testThree',  ['PHP'        => '2.0']],
+            ['testFour',   ['PHPUnit'    => '2.0', 'PHP' => '1.0']],
+            ['testFive',   ['PHP'        => '5.4.0RC6']],
+            ['testSix',    ['PHP'        => '5.4.0-alpha1']],
+            ['testSeven',  ['PHP'        => '5.4.0beta2']],
+            ['testEight',  ['PHP'        => '5.4-dev']],
+            ['testNine',   ['functions'  => ['testFunc']]],
+            ['testTen',    ['extensions' => ['testExt']]],
+            ['testEleven', ['OS'         => '/Linux/i']],
+            [
               'testSpace',
-              array(
-                'extensions' => array('spl'),
+              [
+                'extensions' => ['spl'],
                 'OS'         => '/.*/i'
-              )
-            ),
-            array(
+              ]
+            ],
+            [
               'testAllPossibleRequirements',
-              array(
+              [
                 'PHP'       => '99-dev',
                 'PHPUnit'   => '9-dev',
                 'OS'        => '/DOESNOTEXIST/i',
-                'functions' => array(
+                'functions' => [
                   'testFuncOne',
                   'testFuncTwo',
-                ),
-                'extensions' => array(
+                ],
+                'extensions' => [
                   'testExtOne',
                   'testExtTwo',
-                )
-              )
-            )
-        );
+                ]
+              ]
+            ]
+        ];
     }
 
     /**
@@ -172,19 +176,19 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
      */
     public function testGetRequirementsMergesClassAndMethodDocBlocks()
     {
-        $expectedAnnotations = array(
+        $expectedAnnotations = [
             'PHP'       => '5.4',
             'PHPUnit'   => '3.7',
             'OS'        => '/WINNT/i',
-            'functions' => array(
+            'functions' => [
               'testFuncClass',
               'testFuncMethod',
-            ),
-            'extensions' => array(
+            ],
+            'extensions' => [
               'testExtClass',
               'testExtMethod',
-            )
-        );
+            ]
+        ];
 
         $this->assertEquals(
             $expectedAnnotations,
@@ -206,14 +210,14 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
 
     public function missingRequirementsProvider()
     {
-        return array(
-            array('testOne',            array()),
-            array('testNine',           array('Function testFunc is required.')),
-            array('testTen',            array('Extension testExt is required.')),
-            array('testAlwaysSkip',     array('PHPUnit 1111111 (or later) is required.')),
-            array('testAlwaysSkip2',    array('PHP 9999999 (or later) is required.')),
-            array('testAlwaysSkip3',    array('Operating system matching /DOESNOTEXIST/i is required.')),
-            array('testAllPossibleRequirements', array(
+        return [
+            ['testOne',            []],
+            ['testNine',           ['Function testFunc is required.']],
+            ['testTen',            ['Extension testExt is required.']],
+            ['testAlwaysSkip',     ['PHPUnit 1111111 (or later) is required.']],
+            ['testAlwaysSkip2',    ['PHP 9999999 (or later) is required.']],
+            ['testAlwaysSkip3',    ['Operating system matching /DOESNOTEXIST/i is required.']],
+            ['testAllPossibleRequirements', [
               'PHP 99-dev (or later) is required.',
               'PHPUnit 9-dev (or later) is required.',
               'Operating system matching /DOESNOTEXIST/i is required.',
@@ -221,12 +225,13 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
               'Function testFuncTwo is required.',
               'Extension testExtOne is required.',
               'Extension testExtTwo is required.',
-            )),
-        );
+            ]],
+        ];
     }
 
     /**
      * @coversNothing
+     *
      * @todo   This test does not really test functionality of PHPUnit_Util_Test
      */
     public function testGetProvidedDataRegEx()
@@ -252,14 +257,111 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('メソッド', $matches[1]);
     }
 
+    /**
+     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
+     */
+    public function testTestWithEmptyAnnotation()
+    {
+        $result = PHPUnit_Util_Test::getDataFromTestWithAnnotation("/**\n * @anotherAnnotation\n */");
+        $this->assertNull($result);
+    }
+
+    /**
+     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
+     */
+    public function testTestWithSimpleCase()
+    {
+        $result = PHPUnit_Util_Test::getDataFromTestWithAnnotation('/**
+                                                                     * @testWith [1]
+                                                                     */');
+        $this->assertEquals([[1]], $result);
+    }
+
+    /**
+     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
+     */
+    public function testTestWithMultiLineMultiParameterCase()
+    {
+        $result = PHPUnit_Util_Test::getDataFromTestWithAnnotation('/**
+                                                                     * @testWith [1, 2]
+                                                                     * [3, 4]
+                                                                     */');
+        $this->assertEquals([[1, 2], [3, 4]], $result);
+    }
+
+    /**
+     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
+     */
+    public function testTestWithVariousTypes()
+    {
+        $result = PHPUnit_Util_Test::getDataFromTestWithAnnotation('/**
+            * @testWith ["ab"]
+            *           [true]
+            *           [null]
+         */');
+        $this->assertEquals([['ab'], [true], [null]], $result);
+    }
+
+    /**
+     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
+     */
+    public function testTestWithAnnotationAfter()
+    {
+        $result = PHPUnit_Util_Test::getDataFromTestWithAnnotation('/**
+                                                                     * @testWith [1]
+                                                                     *           [2]
+                                                                     * @annotation
+                                                                     */');
+        $this->assertEquals([[1], [2]], $result);
+    }
+
+    /**
+     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
+     */
+    public function testTestWithSimpleTextAfter()
+    {
+        $result = PHPUnit_Util_Test::getDataFromTestWithAnnotation('/**
+                                                                     * @testWith [1]
+                                                                     *           [2]
+                                                                     * blah blah
+                                                                     */');
+        $this->assertEquals([[1], [2]], $result);
+    }
+
+    /**
+     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
+     */
+    public function testTestWithCharacterEscape()
+    {
+        $result = PHPUnit_Util_Test::getDataFromTestWithAnnotation('/**
+                                                                     * @testWith ["\"", "\""]
+                                                                     */');
+        $this->assertEquals([['"', '"']], $result);
+    }
+
+    /**
+     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
+     */
+    public function testTestWithThrowsProperExceptionIfDatasetCannotBeParsed()
+    {
+        $this->setExpectedExceptionRegExp(
+            'PHPUnit_Framework_Exception',
+            '/^The dataset for the @testWith annotation cannot be parsed.$/'
+        );
+        PHPUnit_Util_Test::getDataFromTestWithAnnotation('/**
+                                                           * @testWith [s]
+                                                           */');
+    }
+
     /**
      * @covers PHPUnit_Util_Test::getDependencies
+     *
      * @todo   Not sure what this test tests (name is misleading at least)
      */
     public function testParseAnnotation()
     {
         $this->assertEquals(
-            array('Foo', 'ほげ'),
+            ['Foo', 'ほげ'],
             PHPUnit_Util_Test::getDependencies(get_class($this), 'methodForTestParseAnnotation')
         );
     }
@@ -267,6 +369,7 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
     /**
      * @depends Foo
      * @depends ほげ
+     *
      * @todo    Remove fixture from test class
      */
     public function methodForTestParseAnnotation()
@@ -279,7 +382,7 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
     public function testParseAnnotationThatIsOnlyOneLine()
     {
         $this->assertEquals(
-            array('Bar'),
+            ['Bar'],
             PHPUnit_Util_Test::getDependencies(get_class($this), 'methodForTestParseAnnotationThatIsOnlyOneLine')
         );
     }
@@ -299,19 +402,19 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
     public function testGetLinesToBeCovered($test, $lines)
     {
         if (strpos($test, 'Namespace') === 0) {
-            $expected = array(
+            $expected = [
               TEST_FILES_PATH . 'NamespaceCoveredClass.php' => $lines
-            );
+            ];
         } elseif ($test === 'CoverageNoneTest') {
-            $expected = array();
+            $expected = [];
         } elseif ($test === 'CoverageNothingTest') {
             $expected = false;
         } elseif ($test === 'CoverageFunctionTest') {
-            $expected = array(
+            $expected = [
               TEST_FILES_PATH . 'CoveredFunction.php' => $lines
-            );
+            ];
         } else {
-            $expected = array(TEST_FILES_PATH . 'CoveredClass.php' => $lines);
+            $expected = [TEST_FILES_PATH . 'CoveredClass.php' => $lines];
         }
 
         $this->assertEquals(
@@ -368,7 +471,7 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
     public function testGetLinesToBeCoveredSkipsNonExistentMethods()
     {
         $this->assertSame(
-            array(),
+            [],
             PHPUnit_Util_Test::getLinesToBeCovered(
                 'NotExistingCoveredElementTest',
                 'methodDoesNotExist'
@@ -396,7 +499,7 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
     public function testFunctionParenthesesAreAllowed()
     {
         $this->assertSame(
-            array(TEST_FILES_PATH . 'CoveredFunction.php' => range(2, 4)),
+            [TEST_FILES_PATH . 'CoveredFunction.php' => range(2, 4)],
             PHPUnit_Util_Test::getLinesToBeCovered(
                 'CoverageFunctionParenthesesTest',
                 'testSomething'
@@ -411,7 +514,7 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
     public function testFunctionParenthesesAreAllowedWithWhitespace()
     {
         $this->assertSame(
-            array(TEST_FILES_PATH . 'CoveredFunction.php' => range(2, 4)),
+            [TEST_FILES_PATH . 'CoveredFunction.php' => range(2, 4)],
             PHPUnit_Util_Test::getLinesToBeCovered(
                 'CoverageFunctionParenthesesWhitespaceTest',
                 'testSomething'
@@ -426,7 +529,7 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
     public function testMethodParenthesesAreAllowed()
     {
         $this->assertSame(
-            array(TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35)),
+            [TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35)],
             PHPUnit_Util_Test::getLinesToBeCovered(
                 'CoverageMethodParenthesesTest',
                 'testSomething'
@@ -441,7 +544,7 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
     public function testMethodParenthesesAreAllowedWithWhitespace()
     {
         $this->assertSame(
-            array(TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35)),
+            [TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35)],
             PHPUnit_Util_Test::getLinesToBeCovered(
                 'CoverageMethodParenthesesWhitespaceTest',
                 'testSomething'
@@ -449,105 +552,122 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
         );
     }
 
-    public function getLinesToBeCoveredProvider()
+    /**
+     * @covers PHPUnit_Util_Test::getLinesToBeCovered
+     * @covers PHPUnit_Util_Test::getLinesToBeCoveredOrUsed
+     */
+    public function testNamespacedFunctionCanBeCoveredOrUsed()
     {
-        return array(
-          array(
-            'CoverageNoneTest',
-            array()
-          ),
-          array(
-            'CoverageClassExtendedTest',
-            array_merge(range(19, 36), range(2, 17))
-          ),
-          array(
-            'CoverageClassTest',
-            range(19, 36)
-          ),
-          array(
-            'CoverageMethodTest',
-            range(31, 35)
-          ),
-          array(
-            'CoverageMethodOneLineAnnotationTest',
-            range(31, 35)
-          ),
-          array(
-            'CoverageNotPrivateTest',
-            array_merge(range(25, 29), range(31, 35))
-          ),
-          array(
-            'CoverageNotProtectedTest',
-            array_merge(range(21, 23), range(31, 35))
-          ),
-          array(
-            'CoverageNotPublicTest',
-            array_merge(range(21, 23), range(25, 29))
-          ),
-          array(
-            'CoveragePrivateTest',
-            range(21, 23)
-          ),
-          array(
-            'CoverageProtectedTest',
-            range(25, 29)
-          ),
-          array(
-            'CoveragePublicTest',
-            range(31, 35)
-          ),
-          array(
-            'CoverageFunctionTest',
-            range(2, 4)
-          ),
-          array(
-            'NamespaceCoverageClassExtendedTest',
-            array_merge(range(21, 38), range(4, 19))
-          ),
-          array(
-            'NamespaceCoverageClassTest',
-            range(21, 38)
-          ),
-          array(
-            'NamespaceCoverageMethodTest',
-            range(33, 37)
-          ),
-          array(
-            'NamespaceCoverageNotPrivateTest',
-            array_merge(range(27, 31), range(33, 37))
-          ),
-          array(
-            'NamespaceCoverageNotProtectedTest',
-            array_merge(range(23, 25), range(33, 37))
-          ),
-          array(
-            'NamespaceCoverageNotPublicTest',
-            array_merge(range(23, 25), range(27, 31))
-          ),
-          array(
-            'NamespaceCoveragePrivateTest',
-            range(23, 25)
-          ),
-          array(
-            'NamespaceCoverageProtectedTest',
-            range(27, 31)
-          ),
-          array(
-            'NamespaceCoveragePublicTest',
-            range(33, 37)
-          ),
-          array(
-            'NamespaceCoverageCoversClassTest',
-            array_merge(range(23, 25), range(27, 31), range(33, 37), range(6, 8), range(10, 13), range(15, 18))
-          ),
-          array(
-            'NamespaceCoverageCoversClassPublicTest',
-            range(33, 37)
-          ),
-          array(
-            'CoverageNothingTest',
-            false
-          )
+        $this->assertEquals(
+            [
+                TEST_FILES_PATH . 'NamespaceCoveredFunction.php' => range(4, 7)
+            ],
+            PHPUnit_Util_Test::getLinesToBeCovered(
+                'CoverageNamespacedFunctionTest',
+                'testFunc'
+            )
         );
     }
+
+    public function getLinesToBeCoveredProvider()
+    {
+        return [
+          [
+            'CoverageNoneTest',
+            []
+          ],
+          [
+            'CoverageClassExtendedTest',
+            array_merge(range(19, 36), range(2, 17))
+          ],
+          [
+            'CoverageClassTest',
+            range(19, 36)
+          ],
+          [
+            'CoverageMethodTest',
+            range(31, 35)
+          ],
+          [
+            'CoverageMethodOneLineAnnotationTest',
+            range(31, 35)
+          ],
+          [
+            'CoverageNotPrivateTest',
+            array_merge(range(25, 29), range(31, 35))
+          ],
+          [
+            'CoverageNotProtectedTest',
+            array_merge(range(21, 23), range(31, 35))
+          ],
+          [
+            'CoverageNotPublicTest',
+            array_merge(range(21, 23), range(25, 29))
+          ],
+          [
+            'CoveragePrivateTest',
+            range(21, 23)
+          ],
+          [
+            'CoverageProtectedTest',
+            range(25, 29)
+          ],
+          [
+            'CoveragePublicTest',
+            range(31, 35)
+          ],
+          [
+            'CoverageFunctionTest',
+            range(2, 4)
+          ],
+          [
+            'NamespaceCoverageClassExtendedTest',
+            array_merge(range(21, 38), range(4, 19))
+          ],
+          [
+            'NamespaceCoverageClassTest',
+            range(21, 38)
+          ],
+          [
+            'NamespaceCoverageMethodTest',
+            range(33, 37)
+          ],
+          [
+            'NamespaceCoverageNotPrivateTest',
+            array_merge(range(27, 31), range(33, 37))
+          ],
+          [
+            'NamespaceCoverageNotProtectedTest',
+            array_merge(range(23, 25), range(33, 37))
+          ],
+          [
+            'NamespaceCoverageNotPublicTest',
+            array_merge(range(23, 25), range(27, 31))
+          ],
+          [
+            'NamespaceCoveragePrivateTest',
+            range(23, 25)
+          ],
+          [
+            'NamespaceCoverageProtectedTest',
+            range(27, 31)
+          ],
+          [
+            'NamespaceCoveragePublicTest',
+            range(33, 37)
+          ],
+          [
+            'NamespaceCoverageCoversClassTest',
+            array_merge(range(23, 25), range(27, 31), range(33, 37), range(6, 8), range(10, 13), range(15, 18))
+          ],
+          [
+            'NamespaceCoverageCoversClassPublicTest',
+            range(33, 37)
+          ],
+          [
+            'CoverageNothingTest',
+            false
+          ]
+        ];
+    }
 }
